@@ -109,7 +109,10 @@
 #define PROD_LIVE_VISTA_IM    0x4052
 #define PROD_LIVE_VISTA_VF0330     0x405f
 #define PROD_LIVE_VISTA_VF0350     0x4060	/* Creative Live Cam */
+#define PROD_LIVE_VISTA_VF0400     0x4061       /* Creative Live! Cam Notebook Pro */
 #define PROD_LIVE_VISTA_VF0420     0x4064
+#define PROD_LIVE_VISTA_VF0350_A   0x4067
+#define PROD_LIVE_VISTA_VF0470     0x4068       /* Creative Live!  Cam Notebook */ 
 
 /* --------------------------------- */
 /*      DEVICE IMPLEMENTATIONS       */
@@ -118,6 +121,7 @@
 enum {
 	IMP_GENERIC,
 	IMP_EYETOY,
+	IMP_LIVE,
 };
 
 /* --------------------------------- */
@@ -444,6 +448,7 @@ enum {
 	LED_OFF,
 	LED_ON,
 	LED_AUTO,
+	LED_AUTO_REVERSE,
 };
 
 /* Raw frame formats */
